/*
filename : init.js
version  : 1.1 (12.11.2014)
author   : Nicolas Baudet <www.baudet.me>
since    : 19.06.2014

Copyright (C) 2014 Nicolas Baudet

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

/*********************************
VARIABLES GLOBALES
*********************************/
var fadeDuration = 200;

/*********************************
FONCTION GLOBALES
*********************************/
// Remet tous les champs du formulaire à zéro.
function raz(){
	$("form").find("input[type=text], textarea").each(function(){
		$(this).val("");
	});
	var editors = tinymce.EditorManager.editors;
	for (var key in editors){
	    tinymce.get(key).setContent('');
	}
	$("#couleur option").each(function(){
		$(this).attr("selected", false);
	});
	$("#langue option").each(function(){
		$(this).attr("selected", false);
	});
}

/* Contrôle les champs du formulaire en vue de l'exportation.
   Renvoie true ou false. */
function isFormOK(){
	formOK = true;

	$("form").find("input[type=text]").each(function(){
		if($(this).val() == "")
			formOK = false;
	});

	return formOK;
}

/*********************************
GESTION DES CLICKS SUR LES BOUTONS
*********************************/
// Affichage des informations
$("#infoButton").click(function(){
	$("#info").toggle(400);
})

// Vidage du contenu du formulaire
$("#emptyForm").click(function(){
	event.preventDefault();
	raz();
});

// Fermeture du libellé de drag&drop
$("#closeDragover").click(function(){
	event.preventDefault();
	$("#dragover").fadeOut(fadeDuration);
})

/* Génération de la fiche article WinBIZ */
$("#generate").click(function(){
	$("#generationMethod").val("default");
})

/* Génération de la fiche article PDF */
$("#generatePdf").click(function(){
	$("#generationMethod").val("pdf");
})

// Lecture du fichier droppé (seulement les *.txt sont acceptés)
function readFile(file) {

    if (!file.type.match("text/plain")) {
    	alert("Erreur ! Cette webapp n'accepte que les fichiers *.txt.");
        return false;
    }
    
   	// Définition des champs
	$("#nom").val(file.name.substring(0, file.name.length-4));

    // Création du file reader
    var reader = new FileReader();
    reader.onload = (function(file) {
    	return function(e) {
    		// Parsage du fichier reçu par HTML
	    	var content = $.parseHTML(reader.result);

	    	// Déduction de la langue
	    	switch($(content).find("h3").eq(1).html()) {
	    		case "Producteur":
	    			$('#langue option[value="FR"]').prop('selected', true);
	    			break;
	    		case "Produzent":
	    			$('#langue option[value="DE"]').prop('selected', true);
	    			break;
	    	}

	    	// On enlève les titres inutiles
	    	$(content).find("h3").each(function(){
	    		this.remove();
	    	})
	    	
			//console.log($(content).find(".nom_produit").html());
			
			if ($(content).find(".nom_produit").html() != undefined) {
				tinyMCE.get("nom_produit").setContent($(content).find(".nom_produit").html());
			}
			if ($(content).find(".domaine").html() != undefined) {
				tinyMCE.get("domaine").setContent($(content).find(".domaine").html());
			}
			
	        $("#appellation").val($(content).find(".appellation").text());
	        $("#producteur").val($(content).find(".producteur").text());
	        
	        var couleur = $(content).find(".couleur").text();
	        $("select#couleur option").filter(function() {
			    return $(this).val() == $.trim(couleur);
			}).attr('selected', true);

	        $("#cepage").val($(content).find(".cepage").text());
	        $("#esprit").val($(content).find(".esprit").text());
	        $("#terroir").val($(content).find(".terroir").text());
	        $("#culture").val($(content).find(".culture").text());
	        $("#vinification").val($(content).find(".vinification").text());

			if ($(content).find(".degustation").html() != undefined) {
				tinyMCE.get("degustation").setContent($(content).find(".degustation").html());
			}
	        if ($(content).find(".mets").html() != undefined) {
				tinyMCE.get("mets").setContent($(content).find(".mets").html());
			}
	        
	        $("#service").val($(content).find(".service").text());
	        $("#distinction").val($(content).find(".distinction").text());
	    };
	})(file);
	reader.readAsText(file);
}

/*********************************
GESTION DU DRAG & DROP
**********************************
Sources :
http://www.devarticles.com/c/a/HTML/Drag-and-Drop-in-HTML5-Parsing-Local-Files/1/
http://www.html5rocks.com/en/tutorials/dnd/basics/
http://www.html5rocks.com/en/tutorials/file/dndfiles/#toc-selecting-files-dnd
*********************************/
/* Initialise les events, gère les fichiers droppés et configure tinymce */
function initialize() {
    // get the file container
    var filecont = document.body;
    if (filecont === null) {
        return false;
    }
    
    // attach the 'dragover' event to the file container
    filecont.addEventListener('dragover', function(event) {
        event.preventDefault();
        $("#dragover").fadeIn(fadeDuration);
        return false;
    }, false);
    
    // attach the 'drop' event to the file container
    filecont.addEventListener('drop', function(event) {
        event.preventDefault();
		$("#dragover").fadeOut(fadeDuration);

        var files = event.dataTransfer.files;
        if(files.length > 1) {
        	alert("Erreur, il ne faut drag & droper qu'un fichier *.txt à la fois.");
        }
        else if(files.length == 1) {
        	raz();
        	readFile(files[0]);
        }
        return false;
    }, false);

    // Ajoute l'éditeur aux textareas de la page
    tinymce.init({
    	selector: "textarea",
    	menubar: false,
    	statusbar: false,
    	content_css : "css/customTinyMCE.css",
    	toolbar: [
	        "undo redo | cut copy paste | removeformat | bold italic | alignleft aligncenter alignright | bullist numlist"
    	]
    });

    // Vérifie que l'explorateur supporte les API de gestion des fichiers
	if (window.File && window.FileReader && window.FileList && window.Blob) {
	  // Tout va bien !
	} else {
	  alert("Erreur ! Cet explorateur n'est pas assez récent et ne supporte pas cette webapp. Veuillez utiliser un explorateur comme Chrome ou Firefox.");
	}

	$("#nom").focus();
}

// Initialise l'ensemble quand le chargement est fini.
window.addEventListener('load', initialize, true);